==> te-2.6.2.zip: te/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'విషయానికి';
$GLOBALS['__l10n']['To menu'] = 'మెనూకి';
$GLOBALS['__l10n']['To search'] = 'అన్వేషణకి';
$GLOBALS['__l10n']['By'] = 'రాసినది';
$GLOBALS['__l10n']['by'] = 'రాసినది';
$GLOBALS['__l10n']['on'] = 'తేదీ';
$GLOBALS['__l10n']['On'] = 'తేదీ';
$GLOBALS['__l10n']['Continue reading'] = 'చదవడం కొనసాగించండి';
$GLOBALS['__l10n']['no comment'] = 'వ్యాఖ్యలు లేవు';
$GLOBALS['__l10n']['one comment'] = 'ఒక వ్యాఖ్య';
$GLOBALS['__l10n']['%d comments'] = '%d వ్యాఖ్యలు';
$GLOBALS['__l10n']['no trackback'] = 'ట్రాకుబ్యాకులు లేవు';
$GLOBALS['__l10n']['one trackback'] = 'ఒక ట్రాకుబ్యాకు';
$GLOBALS['__l10n']['%d trackbacks'] = '%d ట్రాకుబ్యాకులు';
$GLOBALS['__l10n']['no attachment'] = 'జోడింపులు లేవు';
$GLOBALS['__l10n']['one attachment'] = 'ఒక జోడింపు';
$GLOBALS['__l10n']['%d attachments'] = '%d జోడింపులు';
$GLOBALS['__l10n']['previous entries'] = 'గత టపాలు';
$GLOBALS['__l10n']['page'] = 'పేజీ';
$GLOBALS['__l10n']['of'] = 'యొక్క';
$GLOBALS['__l10n']['next entries'] = 'తర్వాతి టపాలు';
$GLOBALS['__l10n']['Search'] = 'వెతుకు';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '<p>మీ అన్వేషణకి ఫలితాలేమీ లేవు.</p>';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = 'వాకిలి';
$GLOBALS['__l10n']['All keywords'] = 'అన్ని కీపదాలు';
$GLOBALS['__l10n']['Best of me'] = 'ఉత్తమం';
$GLOBALS['__l10n']['Languages'] = 'భాషలు';
$GLOBALS['__l10n']['Categories'] = 'వర్గాలు';
$GLOBALS['__l10n']['Subcategories'] = 'వర్గాలు';
$GLOBALS['__l10n']['Archives'] = 'కైఫీయతులు';
$GLOBALS['__l10n']['Links'] = 'లంకెలు';
$GLOBALS['__l10n']['Subscribe'] = 'చందాచేరండి';
$GLOBALS['__l10n']['Entries feed'] = 'టపాల ఫీడు';
$GLOBALS['__l10n']['Comments feed'] = 'వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'ఈ బ్లాగు యొక్క వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'ఈ వర్గంలోని టపాల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'ఈ వర్గంలోని వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'ఈ టపా యొక్క వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'ఈ టపా యొక్క వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['Attachments'] = 'జోడింపులు';
$GLOBALS['__l10n']['Permalink'] = 'స్థిరలింకు';
$GLOBALS['__l10n']['Comments'] = 'వ్యాఖ్యలు';
$GLOBALS['__l10n']['Your comment'] = 'మీ వ్యాఖ్య';
$GLOBALS['__l10n']['Your comment has been published.'] = 'మీ వ్యాఖ్యని ప్రచురించాం.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'మీ వ్యాఖ్య దాఖలైంది మరియు ప్రచురణకై సమీక్షించబడుతుంది.';
$GLOBALS['__l10n']['Add a comment'] = 'ఓ వ్యాఖ్య చేర్చండి';
$GLOBALS['__l10n']['Name or nickname'] = 'పేరు లేదా ముద్దుపేరు';
$GLOBALS['__l10n']['Email address'] = 'ఈమెయిలు చిరునామా';
$GLOBALS['__l10n']['Website'] = 'వెబ్ సైటు';
$GLOBALS['__l10n']['optional'] = 'ఐచ్ఛికం';
$GLOBALS['__l10n']['Comment'] = 'వ్యాఖ్య';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML సంకేతాన్ని పాఠ్యంగా చూపిస్తాం మరియు వెబ్ చిరునామాలని ఆటోమెటిగ్గా లింకులుగా చూపిస్తాం.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'ఈ బ్లాగులో నన్ను గుర్తుంచుకో';
$GLOBALS['__l10n']['preview'] = 'మునుజూపు';
$GLOBALS['__l10n']['send'] = 'పంపించు';
$GLOBALS['__l10n']['They posted on the same topic'] = 'వాళ్ళు ఇదే విషయంపై వ్రాసారు';
$GLOBALS['__l10n']['Trackback URL'] = 'ట్రాకుబ్యాకు URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'రచయిత పేరు తప్పనిసరిగా ఇవ్వాలి';
$GLOBALS['__l10n']['You must provide a comment'] = 'మీరు తప్పనిసరిగా వ్యాఖ్యని ఇవ్వాలి';
$GLOBALS['__l10n']['Email address is not valid'] = 'ఈమెయిలు చిరునామా సరైనది కాదు';
$GLOBALS['__l10n']['Document not found'] = 'పత్రం కనబడలేదు';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'మీరు వెతుకుతున్న పత్రం ఇక్కడ లేదు.';
$GLOBALS['__l10n']['Powered by %s'] = '%s తో శక్తిమంతం';
$GLOBALS['__l10n']['Subscribe to'] = 'చందాచేరండి';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'RSS ఫీడు అంటే ఏమిటి?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS ఫీడు అనేది ఉచిత బ్లాగు సంగ్రహం. అది విషయాన్ని (టపాలు లేదా వ్యాఖ్యలు) గానీ లేదా వాటి సంగ్రహాన్ని గానీ వాటి పూర్తి కూర్పులకి లింకులతో మరియు ఇతర సంబంధిత సమాచారంతో అందిస్తుంది. కొత్తగా ప్రచురించిన అంశాలను మీ అభిమాన RSS <a href="http://en.wikipedia.org/wiki/Aggregator">సంకలినిలో</a> చదువుకోవచ్చు.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'ఈ URLని మీ సంకలిని లోనికి కాపీ చెయ్యండి:';
$GLOBALS['__l10n']['Password needed'] = 'సంకేతపదం కావాలి';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'ఈ ప్రదేశాన్ని చూడడానికి మీరు సంకేతపదం ఇవ్వాలి.';
$GLOBALS['__l10n']['Password:'] = 'సంకేతపదం:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'మీరు తప్పనిసరిగా ఓ సరైన ఈమెయిల్ చిరునామా ఇవ్వాలి.';
$GLOBALS['__l10n']['Read'] = 'చదవండి';

==> te-2.7.3.zip: te/public.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2013 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#		  DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['To content'] = 'విషయానికి';
$GLOBALS['__l10n']['To menu'] = 'మెనూకి';
$GLOBALS['__l10n']['To search'] = 'అన్వేషణకి';
$GLOBALS['__l10n']['By'] = 'రాసినది';
$GLOBALS['__l10n']['by'] = 'రాసినది';
$GLOBALS['__l10n']['on'] = 'తేదీ';
$GLOBALS['__l10n']['On'] = 'తేదీ';
$GLOBALS['__l10n']['Continue reading'] = 'చదవడం కొనసాగించండి';
$GLOBALS['__l10n']['no comments'] = 'వ్యాఖ్యలు లేవు';
$GLOBALS['__l10n']['one comment'] = 'ఒక వ్యాఖ్య';
$GLOBALS['__l10n']['%d comments'] = '%d వ్యాఖ్యలు';
$GLOBALS['__l10n']['no trackbacks'] = 'ట్రాకుబ్యాకులు లేవు';
$GLOBALS['__l10n']['one trackback'] = 'ఒక ట్రాకుబ్యాకు';
$GLOBALS['__l10n']['%d trackbacks'] = '%d ట్రాకుబ్యాకులు';
$GLOBALS['__l10n']['no attachments'] = 'జోడింపులు లేవు';
$GLOBALS['__l10n']['one attachment'] = 'ఒక జోడింపు';
$GLOBALS['__l10n']['%d attachments'] = '%d జోడింపులు';
$GLOBALS['__l10n']['previous entries'] = 'గత టపాలు';
$GLOBALS['__l10n']['page'] = 'పేజీ';
$GLOBALS['__l10n']['of'] = 'యొక్క';
$GLOBALS['__l10n']['next entries'] = 'తర్వాతి టపాలు';
$GLOBALS['__l10n']['Search'] = 'వెతుకు';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned no result.'] = '<p>మీ అన్వేషణకి ఫలితాలేమీ లేవు.</p>';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = '';
$GLOBALS['__l10n']['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = '';
$GLOBALS['__l10n']['Home'] = 'వాకిలి';
$GLOBALS['__l10n']['All keywords'] = 'అన్ని కీపదాలు';
$GLOBALS['__l10n']['Best of me'] = 'ఉత్తమం';
$GLOBALS['__l10n']['Languages'] = 'భాషలు';
$GLOBALS['__l10n']['Categories'] = 'వర్గాలు';
$GLOBALS['__l10n']['Subcategories'] = 'వర్గాలు';
$GLOBALS['__l10n']['Archives'] = 'కైఫీయతులు';
$GLOBALS['__l10n']['Links'] = 'లంకెలు';
$GLOBALS['__l10n']['Subscribe'] = 'చందాచేరండి';
$GLOBALS['__l10n']['Entries feed'] = 'టపాల ఫీడు';
$GLOBALS['__l10n']['Comments feed'] = 'వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['This blog\'s comments Atom feed'] = 'ఈ బ్లాగు యొక్క వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This category\'s entries Atom feed'] = 'ఈ వర్గంలోని టపాల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This category\'s comments Atom feed'] = 'ఈ వర్గంలోని వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['This post\'s comments feed'] = 'ఈ టపా యొక్క వ్యాఖ్యల ఫీడు';
$GLOBALS['__l10n']['This post\'s comments Atom feed'] = 'ఈ టపా యొక్క వ్యాఖ్యల ఆటమ్ ఫీడు';
$GLOBALS['__l10n']['Attachments'] = 'జోడింపులు';
$GLOBALS['__l10n']['Permalink'] = 'స్థిరలింకు';
$GLOBALS['__l10n']['Comments'] = 'వ్యాఖ్యలు';
$GLOBALS['__l10n']['Your comment'] = 'మీ వ్యాఖ్య';
$GLOBALS['__l10n']['Your comment has been published.'] = 'మీ వ్యాఖ్యని ప్రచురించాం.';
$GLOBALS['__l10n']['Your comment has been submitted and will be reviewed for publication.'] = 'మీ వ్యాఖ్య దాఖలైంది మరియు ప్రచురణకై సమీక్షించబడుతుంది.';
$GLOBALS['__l10n']['Add a comment'] = 'ఓ వ్యాఖ్య చేర్చండి';
$GLOBALS['__l10n']['Name or nickname'] = 'పేరు లేదా ముద్దుపేరు';
$GLOBALS['__l10n']['Email address'] = 'ఈమెయిలు చిరునామా';
$GLOBALS['__l10n']['Website'] = 'వెబ్ సైటు';
$GLOBALS['__l10n']['optional'] = 'ఐచ్ఛికం';
$GLOBALS['__l10n']['Comment'] = 'వ్యాఖ్య';
$GLOBALS['__l10n']['Comments can be formatted using a simple wiki syntax.'] = '';
$GLOBALS['__l10n']['HTML code is displayed as text and web addresses are automatically converted.'] = 'HTML సంకేతాన్ని పాఠ్యంగా చూపిస్తాం మరియు వెబ్ చిరునామాలని ఆటోమెటిగ్గా లింకులుగా చూపిస్తాం.';
$GLOBALS['__l10n']['Remember me on this blog'] = 'ఈ బ్లాగులో నన్ను గుర్తుంచుకో';
$GLOBALS['__l10n']['preview'] = 'మునుజూపు';
$GLOBALS['__l10n']['send'] = 'పంపించు';
$GLOBALS['__l10n']['They posted on the same topic'] = 'వాళ్ళు ఇదే విషయంపై వ్రాసారు';
$GLOBALS['__l10n']['Trackback URL'] = 'ట్రాకుబ్యాకు URL';
$GLOBALS['__l10n']['You must provide an author name'] = 'రచయిత పేరు తప్పనిసరిగా ఇవ్వాలి';
$GLOBALS['__l10n']['You must provide a comment'] = 'మీరు తప్పనిసరిగా వ్యాఖ్యని ఇవ్వాలి';
$GLOBALS['__l10n']['Email address is not valid'] = 'ఈమెయిలు చిరునామా సరైనది కాదు';
$GLOBALS['__l10n']['Document not found'] = 'పత్రం కనబడలేదు';
$GLOBALS['__l10n']['The document you are looking for does not exist.'] = 'మీరు వెతుకుతున్న పత్రం ఇక్కడ లేదు.';
$GLOBALS['__l10n']['Powered by %s'] = '%s తో శక్తిమంతం';
$GLOBALS['__l10n']['Subscribe to'] = 'చందాచేరండి';
$GLOBALS['__l10n']['What is an RSS feed?'] = 'RSS ఫీడు అంటే ఏమిటి?';
$GLOBALS['__l10n']['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'RSS ఫీడు అనేది ఉచిత బ్లాగు సంగ్రహం. అది విషయాన్ని (టపాలు లేదా వ్యాఖ్యలు) గానీ లేదా వాటి సంగ్రహాన్ని గానీ వాటి పూర్తి కూర్పులకి లింకులతో మరియు ఇతర సంబంధిత సమాచారంతో అందిస్తుంది. కొత్తగా ప్రచురించిన అంశాలను మీ అభిమాన RSS <a href="http://en.wikipedia.org/wiki/Aggregator">సంకలినిలో</a> చదువుకోవచ్చు.';
$GLOBALS['__l10n']['Simply copy the following URL into your aggregator:'] = 'ఈ URLని మీ సంకలిని లోనికి కాపీ చెయ్యండి:';
$GLOBALS['__l10n']['Password needed'] = 'సంకేతపదం కావాలి';
$GLOBALS['__l10n']['You must give a password to access this area.'] = 'ఈ ప్రదేశాన్ని చూడడానికి మీరు సంకేతపదం ఇవ్వాలి.';
$GLOBALS['__l10n']['Password:'] = 'సంకేతపదం:';
$GLOBALS['__l10n']['You must provide a valid email address.'] = 'మీరు తప్పనిసరిగా ఓ సరైన ఈమెయిల్ చిరునామా ఇవ్వాలి.';
$GLOBALS['__l10n']['Read'] = 'చదవండి';
